==> qtjambi-bluetooth-debuginfo-macos-5.15.18.jar: sources/QtJambiBluetooth/QBluetoothServiceInfo_Sequence_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtBluetooth/qbluetoothserviceinfo.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include "hashes.h"

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QBluetoothServiceInfo_Sequence(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBluetoothServiceInfo::Sequence")
    QBluetoothServiceInfo::Sequence *_ptr = reinterpret_cast<QBluetoothServiceInfo::Sequence *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Sequence()
void __qt_construct_QBluetoothServiceInfo_Sequence_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Sequence()")
    Q_UNUSED(__java_arguments)
    QBluetoothServiceInfo::Sequence *__qt_this = new(__qtjambi_ptr) QBluetoothServiceInfo::Sequence();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new Sequence(QList<QVariant>)
void __qt_construct_QBluetoothServiceInfo_Sequence_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Sequence(QList<QVariant>)")
    QtJambiScope __qtjambi_scope;
    jobject list0 = __java_arguments[0].l;
    const QList<QVariant>&  __qt_list0 = qtjambi_cast<const QList<QVariant>& >(__jni_env, __qtjambi_scope, list0);
    QBluetoothServiceInfo::Sequence *__qt_this = new(__qtjambi_ptr) QBluetoothServiceInfo::Sequence(__qt_list0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QBluetoothServiceInfo::Sequence
void __qt_destruct_QBluetoothServiceInfo_Sequence(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBluetoothServiceInfo::Sequence")
    typedef QBluetoothServiceInfo::Sequence DESTRUCTOR;
    reinterpret_cast<QBluetoothServiceInfo::Sequence*>(ptr)->~DESTRUCTOR();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBluetoothServiceInfo::Sequence::Sequence()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_initialize_1native__Lio_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothServiceInfo::Sequence::Sequence()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothServiceInfo_Sequence_0, sizeof(QBluetoothServiceInfo::Sequence), typeid(QBluetoothServiceInfo::Sequence), false, QtJambiPrivate::QListAccess<QVariant>::newInstance(), &deleter_QBluetoothServiceInfo_Sequence, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothServiceInfo::Sequence::Sequence(QList<QVariant>)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_initialize_1native__Lio_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_2Ljava_util_Collection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject list0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothServiceInfo::Sequence::Sequence(QList<QVariant>)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = list0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothServiceInfo_Sequence_1, sizeof(QBluetoothServiceInfo::Sequence), typeid(QBluetoothServiceInfo::Sequence), false, QtJambiPrivate::QListAccess<QVariant>::newInstance(), &deleter_QBluetoothServiceInfo_Sequence, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QBluetoothServiceInfo::Sequence *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothServiceInfo::Sequence>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QBluetoothServiceInfo_Sequence(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QBluetoothServiceInfo::Sequence>("QBluetoothServiceInfo::Sequence", "io/qt/bluetooth/QBluetoothServiceInfo$Sequence");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBluetoothServiceInfo_Sequence, {
        ConstructorInfo(&__qt_construct_QBluetoothServiceInfo_Sequence_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QBluetoothServiceInfo_Sequence_1, "Ljava/util/Collection;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBluetoothServiceInfo_Sequence);
    registerMetaType<QBluetoothServiceInfo::Sequence>("QBluetoothServiceInfo::Sequence");
    registerContainerAccessFactory(typeId, NewContainerAccessFunction(&QtJambiPrivate::QListAccess<QVariant>::newInstance));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-bluetooth-debuginfo-macos-5.15.20.jar: sources/QtJambiBluetooth/QBluetoothServiceInfo_Sequence_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtBluetooth/qbluetoothserviceinfo.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include "hashes.h"

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QBluetoothServiceInfo_Sequence(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBluetoothServiceInfo::Sequence")
    QBluetoothServiceInfo::Sequence *_ptr = reinterpret_cast<QBluetoothServiceInfo::Sequence *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Sequence()
void __qt_construct_QBluetoothServiceInfo_Sequence(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Sequence()")
    Q_UNUSED(__java_arguments)
    QBluetoothServiceInfo::Sequence *__qt_this = new(__qtjambi_ptr) QBluetoothServiceInfo::Sequence();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QBluetoothServiceInfo::Sequence::Sequence()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_initialize_1native__Lio_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothServiceInfo::Sequence::Sequence()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothServiceInfo_Sequence, sizeof(QBluetoothServiceInfo::Sequence), typeid(QBluetoothServiceInfo::Sequence), false, QtJambiPrivate::QListAccess<QVariant>::newInstance(), &deleter_QBluetoothServiceInfo_Sequence, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Sequence(QBluetoothServiceInfo::Sequence)
void __qt_construct_QBluetoothServiceInfo_Sequence_cref_QBluetoothServiceInfo_Sequence(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Sequence(QBluetoothServiceInfo::Sequence)")
    jobject other0 = __java_arguments[0].l;
    const QBluetoothServiceInfo::Sequence& __qt_other0 = qtjambi_cast<const QBluetoothServiceInfo::Sequence& >(__jni_env, other0);
    QBluetoothServiceInfo::Sequence *__qt_this = new(__qtjambi_ptr) QBluetoothServiceInfo::Sequence(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QBluetoothServiceInfo::Sequence::Sequence(QBluetoothServiceInfo::Sequence)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_initialize_1native__Lio_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_2Lio_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothServiceInfo::Sequence::Sequence(QBluetoothServiceInfo::Sequence)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothServiceInfo_Sequence_cref_QBluetoothServiceInfo_Sequence, sizeof(QBluetoothServiceInfo::Sequence), typeid(QBluetoothServiceInfo::Sequence), false, QtJambiPrivate::QListAccess<QVariant>::newInstance(), &deleter_QBluetoothServiceInfo_Sequence, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Sequence(QList<QVariant>)
void __qt_construct_QBluetoothServiceInfo_Sequence_cref_QList(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Sequence(QList<QVariant>)")
    QtJambiScope __qtjambi_scope;
    jobject list0 = __java_arguments[0].l;
    const QList<QVariant>&  __qt_list0 = qtjambi_cast<const QList<QVariant>& >(__jni_env, __qtjambi_scope, list0);
    QBluetoothServiceInfo::Sequence *__qt_this = new(__qtjambi_ptr) QBluetoothServiceInfo::Sequence(__qt_list0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QBluetoothServiceInfo::Sequence::Sequence(QList<QVariant>)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_initialize_1native__Lio_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_2Ljava_util_Collection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject list0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothServiceInfo::Sequence::Sequence(QList<QVariant>)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = list0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothServiceInfo_Sequence_cref_QList, sizeof(QBluetoothServiceInfo::Sequence), typeid(QBluetoothServiceInfo::Sequence), false, QtJambiPrivate::QListAccess<QVariant>::newInstance(), &deleter_QBluetoothServiceInfo_Sequence, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QBluetoothServiceInfo::Sequence
void __qt_destruct_QBluetoothServiceInfo_Sequence(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBluetoothServiceInfo::Sequence")
    typedef QBluetoothServiceInfo::Sequence DESTRUCTOR;
    reinterpret_cast<QBluetoothServiceInfo::Sequence*>(ptr)->~DESTRUCTOR();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothServiceInfo_00024Sequence_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QBluetoothServiceInfo::Sequence *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothServiceInfo::Sequence>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QBluetoothServiceInfo_Sequence(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QBluetoothServiceInfo::Sequence>("QBluetoothServiceInfo::Sequence", "io/qt/bluetooth/QBluetoothServiceInfo$Sequence");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBluetoothServiceInfo_Sequence, {
        ConstructorInfo(&__qt_construct_QBluetoothServiceInfo_Sequence, nullptr)
       ,ConstructorInfo(&__qt_construct_QBluetoothServiceInfo_Sequence_cref_QBluetoothServiceInfo_Sequence, "Lio/qt/bluetooth/QBluetoothServiceInfo$Sequence;")
       ,ConstructorInfo(&__qt_construct_QBluetoothServiceInfo_Sequence_cref_QList, "Ljava/util/Collection;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBluetoothServiceInfo_Sequence);
    registerMetaType<QBluetoothServiceInfo::Sequence>("QBluetoothServiceInfo::Sequence");
    registerContainerAccessFactory(typeId, NewContainerAccessFunction(&QtJambiPrivate::QListAccess<QVariant>::newInstance));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
